summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/ui/dlgjabbervcard.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/ui/dlgjabbervcard.cpp')
-rw-r--r--kopete/protocols/jabber/ui/dlgjabbervcard.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kopete/protocols/jabber/ui/dlgjabbervcard.cpp b/kopete/protocols/jabber/ui/dlgjabbervcard.cpp
index 19070798..44278511 100644
--- a/kopete/protocols/jabber/ui/dlgjabbervcard.cpp
+++ b/kopete/protocols/jabber/ui/dlgjabbervcard.cpp
@@ -22,7 +22,7 @@
#include "dlgjabbervcard.h"
-// Qt includes
+// TQt includes
#include <tqtextedit.h>
#include <tqwidgetstack.h>
#include <tqregexp.h>
@@ -56,12 +56,12 @@
#include "dlgvcard.h"
/*
* Constructs a dlgJabberVCard which is a child of 'parent', with the
* name 'name'
*
*/
-dlgJabberVCard::dlgJabberVCard (JabberAccount *account, JabberBaseContact *contact, TQWidget * parent, const char *name)
- : KDialogBase (parent, name, false, i18n("Jabber vCard"), Close | User1 | User2, Close, false, i18n("&Save User Info"), i18n("&Fetch vCard") )
+dlgJabberVCard::dlgJabberVCard (JabberAccount *account, JabberBaseContact *contact, TQWidget * tqparent, const char *name)
+ : KDialogBase (tqparent, name, false, i18n("Jabber vCard"), Close | User1 | User2, Close, false, i18n("&Save User Info"), i18n("&Fetch vCard") )
{
m_account = account;
@@ -92,7 +92,7 @@ dlgJabberVCard::dlgJabberVCard (JabberAccount *account, JabberBaseContact *conta
*/
dlgJabberVCard::~dlgJabberVCard ()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -296,7 +296,7 @@ void dlgJabberVCard::setEnabled(bool state)
void dlgJabberVCard::slotSaveVCard()
{
setEnabled(false);
- m_mainWidget->lblStatus->setText( i18n("Saving vCard to server...") );
+ m_mainWidget->lbltqStatus->setText( i18n("Saving vCard to server...") );
XMPP::VCard vCard;
XMPP::VCard::AddressList addressList;
@@ -418,12 +418,12 @@ void dlgJabberVCard::slotVCardSaved()
if( vCard->success() )
{
- m_mainWidget->lblStatus->setText( i18n("vCard save sucessful.") );
+ m_mainWidget->lbltqStatus->setText( i18n("vCard save sucessful.") );
m_contact->setPropertiesFromVCard( vCard->vcard() );
}
else
{
- m_mainWidget->lblStatus->setText( i18n("Error: Unable to save vCard.") );
+ m_mainWidget->lbltqStatus->setText( i18n("Error: Unable to save vCard.") );
}
setEnabled(true);
@@ -431,7 +431,7 @@ void dlgJabberVCard::slotVCardSaved()
void dlgJabberVCard::slotGetVCard()
{
- m_mainWidget->lblStatus->setText( i18n("Fetching contact vCard...") );
+ m_mainWidget->lbltqStatus->setText( i18n("Fetching contact vCard...") );
setReadOnly(true);
setEnabled(false);
@@ -454,11 +454,11 @@ void dlgJabberVCard::slotGotVCard()
assignContactProperties();
- m_mainWidget->lblStatus->setText( i18n("vCard fetching Done.") );
+ m_mainWidget->lbltqStatus->setText( i18n("vCard fetching Done.") );
}
else
{
- m_mainWidget->lblStatus->setText( i18n("Error: vCard could not be fetched correctly. Check connectivity with the Jabber server.") );
+ m_mainWidget->lbltqStatus->setText( i18n("Error: vCard could not be fetched correctly. Check connectivity with the Jabber server.") );
//it is maybe possible to anyway edit our own vCard (if it is new
if(m_account->myself() == m_contact)
setEnabled( true );
@@ -469,7 +469,7 @@ void dlgJabberVCard::slotSelectPhoto()
{
TQString path;
bool remoteFile = false;
- KURL filePath = KFileDialog::getImageOpenURL( TQString::null, this, i18n( "Jabber Photo" ) );
+ KURL filePath = KFileDialog::getImageOpenURL( TQString(), this, i18n( "Jabber Photo" ) );
if( filePath.isEmpty() )
return;
@@ -493,7 +493,7 @@ void dlgJabberVCard::slotSelectPhoto()
if(img.width() > 96 || img.height() > 96)
{
// Scale and crop the picture.
- img = img.smoothScale( 96, 96, TQImage::ScaleMin );
+ img = img.smoothScale( 96, 96, TQ_ScaleMin );
// crop image if not square
if(img.width() < img.height())
img = img.copy((img.width()-img.height())/2, 0, 96, 96);
@@ -504,7 +504,7 @@ void dlgJabberVCard::slotSelectPhoto()
else if (img.width() < 32 || img.height() < 32)
{
// Scale and crop the picture.
- img = img.smoothScale( 32, 32, TQImage::ScaleMin );
+ img = img.smoothScale( 32, 32, TQ_ScaleMin );
// crop image if not square
if(img.width() < img.height())
img = img.copy((img.width()-img.height())/2, 0, 32, 32);
@@ -520,14 +520,14 @@ void dlgJabberVCard::slotSelectPhoto()
img = img.copy(0, (img.height()-img.width())/2, img.height(), img.height());
}
- m_photoPath = locateLocal("appdata", "jabberphotos/" + m_contact->rosterItem().jid().full().lower().replace(TQRegExp("[./~]"),"-") +".png");
+ m_photoPath = locateLocal("appdata", "jabberphotos/" + m_contact->rosterItem().jid().full().lower().tqreplace(TQRegExp("[./~]"),"-") +".png");
if( img.save(m_photoPath, "PNG") )
{
m_mainWidget->lblPhoto->setPixmap( TQPixmap(img) );
}
else
{
- m_photoPath = TQString::null;
+ m_photoPath = TQString();
}
}
else
@@ -542,12 +542,12 @@ void dlgJabberVCard::slotSelectPhoto()
void dlgJabberVCard::slotClearPhoto()
{
m_mainWidget->lblPhoto->setPixmap( TQPixmap() );
- m_photoPath = TQString::null;
+ m_photoPath = TQString();
}
void dlgJabberVCard::slotOpenURL(const TQString &url)
{
- if ( !url.isEmpty () || (url == TQString::fromLatin1("mailto:") ) )
+ if ( !url.isEmpty () || (url == TQString::tqfromLatin1("mailto:") ) )
new KRun(KURL( url ) );
}
@@ -56,12 +56,12 @@
#include "dlgvcard.h"
/*
- * Constructs a dlgJabberVCard which is a child of 'parent', with the
+ * Constructs a dlgJabberVCard which is a child of 'tqparent', with the
* name 'name'
*